# py-irclib

A Python library for working with the IRC protocol

[![CI - Test](https://github.com/TotallyNotRobots/py-irclib/actions/workflows/python-tests.yml/badge.svg)](https://github.com/TotallyNotRobots/py-irclib/actions/workflows/python-tests.yml)
[![CD - Build](https://github.com/TotallyNotRobots/py-irclib/actions/workflows/python-publish.yml/badge.svg)](https://github.com/TotallyNotRobots/py-irclib/actions/workflows/python-publish.yml)
[![codecov](https://codecov.io/gh/TotallyNotRobots/py-irclib/graph/badge.svg?token=BMp9fmX55x)](https://codecov.io/gh/TotallyNotRobots/py-irclib)


[![PyPI - Version](https://img.shields.io/pypi/v/py-irclib.svg?logo=pypi&label=PyPI&logoColor=gold)](https://pypi.org/project/py-irclib/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/py-irclib.svg?color=blue&label=Downloads&logo=pypi&logoColor=gold)](https://pypi.org/project/py-irclib/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/py-irclib.svg?logo=python&label=Python&logoColor=gold)](https://pypi.org/project/py-irclib/)

[![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![types - Mypy](https://img.shields.io/badge/types-Mypy-blue.svg)](https://github.com/python/mypy)

[![License - MIT](https://img.shields.io/badge/license-MIT-9400d3.svg)](https://spdx.org/licenses/)
